/*
 * Copyright (c) 2007, to-do. All rights reserved.
 */
case K_exec: return _global_exec(ex,argc,argv,res);
case K_getenv: return _global_getenv(ex,argc,argv,res);
case K_setenv: return _global_setenv(ex,argc,argv,res);
case K_system: return _global_system(ex,argc,argv,res);
case K_popen: return _global_popen(ex,argc,argv,res);
case K_load: return _global_load(ex,argc,argv,res);
case K_eval: return _global_eval(ex,argc,argv,res);
case K_print: return _global_print(ex,argc,argv,res);
case K_println: return _global_println(ex,argc,argv,res);
case K_printf: return _global_printf(ex,argc,argv,res);
case K_sprintf: return _global_sprintf(ex,argc,argv,res);
case K_echo: return _global_echo(ex,argc,argv,res);
case K_printfile: return _global_printfile(ex,argc,argv,res);
case K_serial: return _global_serial(ex,argc,argv,res);
case K_unserial: return _global_unserial(ex,argc,argv,res);
case K_tracef: return _global_tracef(ex,argc,argv,res);
case K_traces: return _global_traces(ex,argc,argv,res);
case K_untrace: return _global_untrace(ex,argc,argv,res);
case K_pack: return _global_pack(ex,argc,argv,res);
case K_unpack: return _global_unpack(ex,argc,argv,res);
case K_jconv: return _global_jconv(ex,argc,argv,res);
case K_quote: return _global_quote(ex,argc,argv,res);
case K_unquote: return _global_unquote(ex,argc,argv,res);
case K_entity: return _global_entity(ex,argc,argv,res);
case K_unentity: return _global_unentity(ex,argc,argv,res);
case K_encode: return _global_encode(ex,argc,argv,res);
case K_decode: return _global_decode(ex,argc,argv,res);
case K_crypt: return _global_crypt(ex,argc,argv,res);
case K_md5: return _global_md5(ex,argc,argv,res);
case K_atan2: return _global_atan2(ex,argc,argv,res);
case K_pow: return _global_pow(ex,argc,argv,res);
case K_sin: return _global_sin(ex,argc,argv,res);
case K_asin: return _global_asin(ex,argc,argv,res);
case K_cos: return _global_cos(ex,argc,argv,res);
case K_acos: return _global_acos(ex,argc,argv,res);
case K_tan: return _global_tan(ex,argc,argv,res);
case K_atan: return _global_atan(ex,argc,argv,res);
case K_sqrt: return _global_sqrt(ex,argc,argv,res);
case K_exp: return _global_exp(ex,argc,argv,res);
case K_log: return _global_log(ex,argc,argv,res);
case K_log10: return _global_log10(ex,argc,argv,res);
case K_ceil: return _global_ceil(ex,argc,argv,res);
case K_floor: return _global_floor(ex,argc,argv,res);
case K_round: return _global_round(ex,argc,argv,res);
case K_abs: return _global_abs(ex,argc,argv,res);
case K_rand: return _global_rand(ex,argc,argv,res);
case K_min: return _global_min(ex,argc,argv,res);
case K_max: return _global_max(ex,argc,argv,res);
case K_isfinite: return _global_isfinite(ex,argc,argv,res);
case K_isinf: return _global_isinf(ex,argc,argv,res);
case K_isnan: return _global_isnan(ex,argc,argv,res);
case K_readfile: return _global_readfile(ex,argc,argv,res);
case K_writefile: return _global_writefile(ex,argc,argv,res);
case K_fopen: return _global_fopen(ex,argc,argv,res);
case K_tmpfile: return _global_tmpfile(ex,argc,argv,res);
case K_tempnam: return _global_tempnam(ex,argc,argv,res);
case K_chmod: return _global_chmod(ex,argc,argv,res);
case K_mkdir: return _global_mkdir(ex,argc,argv,res);
case K_touch: return _global_touch(ex,argc,argv,res);
case K_chdir: return _global_chdir(ex,argc,argv,res);
case K_getcwd: return _global_getcwd(ex,argc,argv,res);
case K_rename: return _global_rename(ex,argc,argv,res);
case K_symlink: return _global_symlink(ex,argc,argv,res);
case K_flink: return _global_flink(ex,argc,argv,res);
case K_fcopy: return _global_fcopy(ex,argc,argv,res);
case K_truncate: return _global_truncate(ex,argc,argv,res);
case K_glob: return _global_glob(ex,argc,argv,res);
case K_remove: return _global_remove(ex,argc,argv,res);
case K_unlink: return _global_unlink(ex,argc,argv,res);
case K_fmode: return _global_fmode(ex,argc,argv,res);
case K_fsize: return _global_fsize(ex,argc,argv,res);
case K_fmtime: return _global_fmtime(ex,argc,argv,res);
case K_fctime: return _global_fctime(ex,argc,argv,res);
case K_fatime: return _global_fatime(ex,argc,argv,res);
case K_chown: return _global_chown(ex,argc,argv,res);
case K_fuid: return _global_fuid(ex,argc,argv,res);
case K_fgid: return _global_fgid(ex,argc,argv,res);
case K_dbopen: return _global_dbopen(ex,argc,argv,res);
case K_xmlopen: return _global_xmlopen(ex,argc,argv,res);
case K_mktime: return _global_mktime(ex,argc,argv,res);
case K_timegm: return _global_timegm(ex,argc,argv,res);
case K_time: return _global_time(ex,argc,argv,res);
case K_date: return _global_date(ex,argc,argv,res);
case K_gmdate: return _global_gmdate(ex,argc,argv,res);
case K_putheader: return _global_putheader(ex,argc,argv,res);
case K_setcookie: return _global_setcookie(ex,argc,argv,res);
case K_sendmail: return _global_sendmail(ex,argc,argv,res);
case K_popmail: return _global_popmail(ex,argc,argv,res);
case K_ftpsite: return _global_ftpsite(ex,argc,argv,res);
case K_httpget: return _global_httpget(ex,argc,argv,res);
case K_length: return _global_length(ex,argc,argv,res);
case K_isNull: return _global_isNull(ex,argc,argv,res);
case K_isBool: return _global_isBool(ex,argc,argv,res);
case K_isChar: return _global_isChar(ex,argc,argv,res);
case K_isNumber: return _global_isNumber(ex,argc,argv,res);
case K_isInt: return _global_isInt(ex,argc,argv,res);
case K_isFloat: return _global_isFloat(ex,argc,argv,res);
case K_isString: return _global_isString(ex,argc,argv,res);
case K_isArray: return _global_isArray(ex,argc,argv,res);
case K_isObject: return _global_isObject(ex,argc,argv,res);
case K_toBool: return _global_toBool(ex,argc,argv,res);
case K_toChar: return _global_toChar(ex,argc,argv,res);
case K_toInt: return _global_toInt(ex,argc,argv,res);
case K_toFloat: return _global_toFloat(ex,argc,argv,res);
case K_toNumber: return _global_toNumber(ex,argc,argv,res);
case K_toString: return _global_toString(ex,argc,argv,res);
